Result of lexical analysis produced by the Lexer.
Fields
word: WordContent of the token.
The word value always contains at least one unit, regardless of whether the token is an operator.
id: TokenIdToken identifier.
index: usizePosition of the first character of the word.